@@ -15,14 +15,16 @@ def is_in_past(date):
 
 
 def cache(func):
-    '''Memoization decorator similar to functools.cache (Python 3.9+)'''
+    """Memoization decorator similar to functools.cache (Python 3.9+)"""
     memo = {}
+
     def wrapper(*args, **kwargs):
         kwargs = OrderedDict(sorted(kwargs.items()))
         key = str({"args": args, "kwargs": kwargs})
         if key not in memo:
             memo[key] = func(*args, **kwargs)
         return memo[key]
+
     return wrapper
 
 
@@ -40,7 +42,7 @@ def canonify(string):
 
 
 def user_error(msg):
-    sys.exit(f"{os.path.basename(sys.argv[0])}: " + msg)
+    sys.exit("%s: " % os.path.basename(sys.argv[0]) + msg)
 
 
 def exit_success():
@@ -87,10 +89,14 @@ def get_package_name(url):
     return url.rsplit("/", 1)[-1]
 
 
+def parse_json(text):
+    return json.loads(text, object_pairs_hook=OrderedDict)
+
+
 def read_json(path):
     try:
         with open(path, "r") as f:
-            return json.loads(f.read(), object_pairs_hook=OrderedDict)
+            return parse_json(f.read())
     except FileNotFoundError:
         return None
 
